* --------------------------------------------------------- ba_gm_sub4y
      subroutine ba_gm_sub4y(per, m, rjb, r, 
     :     mech, v30, y, expsiglny,
     :     e_gmpe, amh_gmpe, c_gmpe, amref_gmpe,
     :     rref_gmpe, h_gmpe, 
     :     v30ref, 
     :     a1, pga_low, a2,
     :     sigt_gmpe,
     :     e_pga4nl, amh_pga4nl, c_pga4nl, amref_pga4nl,
     :     rref_pga4nl, h_pga4nl,
     :     pga4nl, fm_pga4nl, fd_pga4nl, fs_pga4nl,
     :     bnl, amp_lin, amp_nl, amp_total,
     :     fm_gmpe, fd_gmpe, fs_gmpe)
 
* Computes TeamX NGA motions for given input variables

* Note: For generality, include a magnitude-dependent anelastic
* term, although the coefficients are 0.0 for the 2007 BA NGA GMPEs

 
* Dates: 08/13/05 - Written by D.M. Boore, based on DMB_NGA.FOR
*        12/12/05 - Written by D. M. Boore, modification of
*                   teamx_gm_suby.  Add an additional distance
*                   term (M-dependence for anelastic attenuation)
*                   --- but not for pga4nl!
*        02/23/06 - Convert from common to natural logs (the
*                   coefficients are for natural log)
*        02/23/06 - Convert output parameter bnl to natural log
*        02/23/06 - Add mechanism
*        03/01/06 - Modify for new coefficient file format (one file
*                   for all mechanisms, including unspecified).
*        07/02/06 - Smooth over kink in nonlin amps
*        07/03/06 - 02/23/06 correction of bnl to natural log was an
*                   error--- the values of bnl (and blin) are the
*                   same for log to any base (because Y ~ (V30/Vref)**blin
*                   and Y ~ (pga4nl/0.1)**bnl).
*        07/03/06 - Allow for cubic smoothing of nonlinear amps.
*        12/01/06 - Changed name of output variable "sigy" to the
*                   more accurate "expsiglny", because the output is
*                   actually e**sig_lnY, not sig_lnY.
*        03/15/07 - Changed names containing "alog" to "aln".
*                   Note that I used "alog" before
*                   because in Fortran "alog" computes "ln"
*                   and "alog10" computes "log", but this could
*                   be confusing when reading the code later.
*        03/18/07 - Trap case of a mechanism with zero coefficient
*                   (as can occur of no events with that mechanism
*                   provided data for a particular period, as happened
*                   for T=10 sec on 18 March 2007).
*        03/20/07 - Cleaned up code portion for calculating the mechanism part
*                   of fm_gmpe (the array specmech is not needed). Deal
*                   with a zero coefficient when mech .ne. 'U' by setting
*                   fm_gmpe = 9.999, so that the computed ground motion
*                   is huge. 
*        10/30/07 - Remove printing to screen,as it hides the printing of
*                   error messages (such as normal fault, T = 10, 
*                   when e3 = 999.99)
*        03/13/08 - pga4nl from BA GMPEs, rather than the equation used to
*                   correct the data before doing the regressions.  The modification
*                   is primarily in the calling program, in specifying the coefficients
*                   for pga4nl, although some of the code here was modified (probably
*                   could use the same for both sources of the pga4nl coefficients
*                   if I altered where the intercept term is applied).

  
      real per, m, rjb, v30, y, sigy
      real e_gmpe(*), c_gmpe(*) 
      real e_pga4nl(*), c_pga4nl(*) 
  
      character mech*(*)
      character nonlin_corr*1
       
     
! Coefficients for pga4nl from GMPE (modification on 13 March 2008):
      r = sqrt(rjb**2+h_pga4nl**2)

      call upstr(mech)
      if (mech .eq. 'U') then
        mechindex = 1
      else if (mech .eq. 'S') then
        mechindex = 2
      else if (mech .eq. 'N') then
        mechindex = 3
      else if (mech .eq. 'R') then
        mechindex = 4
      else
        print *,' mech = '//mech(1:1)//
     :       ' not a valid value; QUITTING'
        stop
      end if
      
      fm_pga4nl_mech = e_pga4nl(mechindex)

      if (m .lt. amh_pga4nl ) then
      
        fm_pga4nl_mscale = e_pga4nl(5)*(m-amh_pga4nl)
     :       + e_pga4nl(6)*(m-amh_pga4nl)**2 
      else
        fm_pga4nl_mscale = e_pga4nl(7)*(m-amh_pga4nl)
     :       + e_pga4nl(8)*(m-amh_pga4nl)**2 
      end if
      
      if (mech .ne. 'U' .and. e_pga4nl(mechindex) .eq. 0.0) then   ! no coefficient
        fm_pga4nl = +9.99
      else
        fm_pga4nl = fm_pga4nl_mech + fm_pga4nl_mscale
      end if

      fd_pga4nl =   c_pga4nl(1)*alog(r/rref_pga4nl)
     :     + c_pga4nl(2)*(m-amref_pga4nl)*alog(r/rref_pga4nl)
     :     + c_pga4nl(3)*(r-rref_pga4nl)
     :     + c_pga4nl(4)*(m-amref_pga4nl)*(r-rref_pga4nl)

      amp_total = 1.0
      fs_pga4nl = alog(amp_total)   ! Natural log!!
         
      alny = fm_pga4nl + fd_pga4nl + fs_pga4nl 
      
      pga4nl = exp(alny)
! Coefficients for pga4nl from GMPE (modification on 13 March 2008):
       
! Old code, using pga4nl coefficients given in first line of coefficient file
** Get pga4nl:
*
*      r = sqrt(rjb**2+h_pga4nl**2)
*
*      if (m .lt. amh_pga4nl ) then
*        fm_pga4nl =   e_pga4nl(1)+e_pga4nl(5)*(m-amh_pga4nl)
*     :       + e_pga4nl(6)*(m-amh_pga4nl)**2 
*      else
*        fm_pga4nl =   e_pga4nl(1)+e_pga4nl(7)*(m-amh_pga4nl)
*      end if
*      
*      fd_pga4nl =   c_pga4nl(1)*alog(r/rref_pga4nl)
*     :     + c_pga4nl(2)*(m-amref_pga4nl)*alog(r/rref_pga4nl)
*     :     + c_pga4nl(3)*(r-rref_pga4nl)
* 
*      fs_pga4nl = 0.0  ! pga4nl is referenced to vref
*      
*      alnpga = fm_pga4nl + fd_pga4nl + fs_pga4nl 
*      
*      pga4nl = exp(alnpga)
*      



* Get y:

      r = sqrt(rjb**2+h_gmpe**2)

      call upstr(mech)
      if (mech .eq. 'U') then
        mechindex = 1
      else if (mech .eq. 'S') then
        mechindex = 2
      else if (mech .eq. 'N') then
        mechindex = 3
      else if (mech .eq. 'R') then
        mechindex = 4
      else
        print *,' mech = '//mech(1:1)//
     :       ' not a valid value; QUITTING'
        stop
      end if
      
      fm_gmpe_mech = e_gmpe(mechindex)

      if (m .lt. amh_gmpe ) then
      
        fm_gmpe_mscale = e_gmpe(5)*(m-amh_gmpe)
     :       + e_gmpe(6)*(m-amh_gmpe)**2 
      else
        fm_gmpe_mscale = e_gmpe(7)*(m-amh_gmpe)
     :       + e_gmpe(8)*(m-amh_gmpe)**2 
      end if
      
      if (mech .ne. 'U' .and. e_gmpe(mechindex) .eq. 0.0) then   ! no coefficient
        fm_gmpe = +9.99
      else
        fm_gmpe = fm_gmpe_mech + fm_gmpe_mscale
      end if

      fd_gmpe =   c_gmpe(1)*alog(r/rref_gmpe)
     :     + c_gmpe(2)*(m-amref_gmpe)*alog(r/rref_gmpe)
     :     + c_gmpe(3)*(r-rref_gmpe)
     :     + c_gmpe(4)*(m-amref_gmpe)*(r-rref_gmpe)

      nonlin_corr = 'Y'

      imodel_lin = 2  ! CS05
      imodel_nl  = 3  ! DMB1
      call site_amp_correction(per, v30, v30ref, 
     :                  imodel_lin, blin, va,
     :                  nonlin_corr, imodel_nl, 
     :                  pga4nl, 
     :                  a1, pga_low, a2,
     :                  bnl, 
     :                  amp_lin, amp_nl, amp_total)
     
!      pganl1 = 0.03
!      pganl2 = 0.09
!
!      if (pga4nl .ge. pganl1 .and. pga4nl .le. pganl2) then
!     
!        fs_lin = alog(amp_lin)
!        
!        dx = alog(pganl2/pganl1)
!        dy = bnl * alog(pganl2/0.06)
!        s2 = bnl
!        b = 0.0
!        c = (3.0*dy/dx-s2)/dx
!        d = (s2-2.0*dy/dx)/dx**2
!        y1 = bnl*alog(0.06/0.1)
!        y2 = bnl*(pganl2/0.1)
!        xmx1 = alog(pga4nl/pganl1)
!      
!        yp3 = y1 + b*xmx1 + c*xmx1**2 + d*xmx1**3
!        
!        fs_nl = yp3
!        
!        amp_nl = exp(fs_nl)
!        
!        amp_total = amp_lin * amp_nl
!        
!        print *,' r, pganl1, pganl2, dx, dy, s2, pga4nl, bnl = ', 
!     :          r, pganl1, pganl2, dx, dy, s2, pga4nl, bnl
!        print *,
!     : ' b, c, d, y1, y2, xmx1, yp3, amp_lin, amp_nl, amp_total = ',
!     :   b, c, d, y1, y2, xmx1, yp3, amp_lin, amp_nl, amp_total
!      
!      end if      
              
      fs_gmpe = alog(amp_total)   ! Natural log!!
         
      alny = fm_gmpe + fd_gmpe + fs_gmpe 
      
!      print *,' fm_gmpe, fd_gmpe, fs_gmpe = ', 
!     :          fm_gmpe, fd_gmpe, fs_gmpe

      y = exp(alny)
       
      expsiglny = exp(sigt_gmpe)
      
  
      return
      end
* --------------------------------------------------------- ba_gm_sub4y


      include '\forprogs\site_amp_correction.for'